@@ -46,7 +46,7 @@ assistant_key_press_event_cb (GtkWidget   *widget,
                               GdkEventKey *event,
                               DhAssistant *assistant)
 {
-        if (event->keyval == GDK_Escape) {
+        if (event->keyval == GDK_KEY_Escape) {
                 gtk_widget_destroy (GTK_WIDGET (assistant));
                 return TRUE;
         }
@@ -66,12 +66,12 @@ dh_assistant_init (DhAssistant *assistant)
         DhAssistantPriv *priv = GET_PRIVATE (assistant);
         GtkWidget       *scrolled_window;
 
-        priv->main_box = gtk_vbox_new (FALSE, 0);
+        priv->main_box = gtk_box_new (GTK_ORIENTATION_VERTICAL, 0);
         gtk_widget_show (priv->main_box);
         gtk_container_add (GTK_CONTAINER (assistant), priv->main_box);
 
         /* i18n: Please don't translate "Devhelp". */
-        gtk_window_set_title (GTK_WINDOW (assistant), _("Devhelp - Assistant"));
+        gtk_window_set_title (GTK_WINDOW (assistant), _("Devhelp — Assistant"));
         gtk_window_set_icon_name (GTK_WINDOW (assistant), "devhelp");
 
         priv->view = dh_assistant_view_new ();
