@@ -465,26 +465,49 @@ dh_util_state_manage_paned (GtkPaned    *paned,
 }
 
 GSList *
-dh_util_state_load_disabled_books (void)
+dh_util_state_load_books_disabled (void)
 {
         gchar *key;
-        GSList *disabled_books = NULL;
+        GSList *books_disabled = NULL;
 
-        key = util_state_get_key ("main/contents", "disabled_books");
-        ige_conf_get_string_list (ige_conf_get (), key, &disabled_books);
-        g_free(key);
+        key = util_state_get_key ("main/contents", "books_disabled");
+        ige_conf_get_string_list (ige_conf_get (), key, &books_disabled);
+        g_free (key);
 
-        return disabled_books;
+        return books_disabled;
 }
 
 void
-dh_util_state_store_disabled_books (GSList *disabled_books)
+dh_util_state_store_books_disabled (GSList *books_disabled)
 {
         gchar *key;
 
-        key = util_state_get_key ("main/contents", "disabled_books");
-        ige_conf_set_string_list (ige_conf_get (), key, disabled_books);
-        g_free(key);
+        key = util_state_get_key ("main/contents", "books_disabled");
+        ige_conf_set_string_list (ige_conf_get (), key, books_disabled);
+        g_free (key);
+}
+
+gboolean
+dh_util_state_load_group_books_by_language (void)
+{
+        gchar *key;
+        gboolean group_books_by_language = FALSE;
+
+        key = util_state_get_key ("main/contents", "group_books_by_language");
+        ige_conf_get_bool (ige_conf_get (), key, &group_books_by_language);
+        g_free (key);
+
+        return group_books_by_language;
+}
+
+void
+dh_util_state_store_group_books_by_language (gboolean group_books_by_language)
+{
+        gchar *key;
+
+        key = util_state_get_key ("main/contents", "group_books_by_language");
+        ige_conf_set_bool (ige_conf_get (), key, group_books_by_language);
+        g_free (key);
 }
 
 static gboolean
@@ -517,7 +540,7 @@ util_state_notebook_timeout_cb (gpointer notebook)
 
 static void
 util_state_notebook_switch_page_cb (GtkWidget       *notebook,
-                                    GtkNotebookPage *page,
+                                    gpointer         page,
                                     guint            page_num,
                                     gpointer         user_data)
 {
@@ -810,3 +833,28 @@ dh_util_cmp_book (DhLink *a, DhLink *b)
         return rc;
 }
 
+/* We're only going to expect ASCII strings here, so there's no point in
+ * playing with g_unichar_totitle() and such.
+ * Note that we modify the string in place.
+ */
+void
+dh_util_ascii_strtitle (gchar *str)
+{
+        gboolean word_start;
+
+        if (!str)
+                return;
+
+        word_start = TRUE;
+        while (*str != '\0') {
+                if (g_ascii_isalpha (*str)) {
+                        *str = (word_start ?
+                                g_ascii_toupper (*str) :
+                                g_ascii_tolower (*str));
+                        word_start = FALSE;
+                } else {
+                        word_start = TRUE;
+                }
+                str++;
+        }
+}
